@@ -9,6 +9,7 @@
 
 #include <sys/stat.h>
 #include <fstream>
+#include <map>
 #include <memory>
 
 #include "xstd/h/new.h"
@@ -530,6 +531,8 @@ ostream &PolyApp::makeAddresses(Array<NetAddr*> &hosts, AddrSyms &agents, ostrea
 }
 
 int PolyApp::makeAddresses(int hidx, AddrSyms &agents, int agentsPerHost) {
+	typedef std::map<String, int> AliasIndexes; // map iface : next free alias index
+	AliasIndexes aliasIndexes;
 	int aliasCount = 0;
 	for (int i = hidx*agentsPerHost; i < agents.count() && aliasCount < agentsPerHost; ++i) {
 
@@ -551,7 +554,14 @@ int PolyApp::makeAddresses(int hidx, AddrSyms &agents, int agentsPerHost) {
 
 		NetIface iface;
 		iface.name(ifName);
-		if (!Should(iface.addAlias(addr.addrN(), aliasCount, netmask))) {
+		std::pair<AliasIndexes::iterator, bool> result =
+			aliasIndexes.insert(std::make_pair(ifName, 0));
+		int &aliasIndex = result.first->second;
+		if (result.second) {
+			// insertion took place, iface is seen for the first time
+			aliasIndex = iface.nextAliasIndex();
+		}
+		if (!Should(iface.addAlias(addr.addrN(), aliasIndex++, netmask))) {
 			agents[i]->print(cerr << "error: " << ifName
 				<< ": failed to create new alias (", "")
 				<< ')' << endl << xexit;
@@ -591,8 +601,7 @@ void PolyApp::deleteAddresses(const String &ifname) {
 
 void PolyApp::addUniqueAddrs(AddrSyms *const addrs, const NetAddrSym &s, HostMap &seen, ostream &skipped) const {
 	int subnet;
-	s.subnet(subnet);
-	if ((subnet || s.val().addrN().family() == AF_INET6) &&
+	if ((s.subnet(subnet) || s.val().addrN().family() == AF_INET6) &&
 		s.ifName()) {
 		const NetAddr addr(s.val().addrN(), -1); // we only care about the IP
 		int idx = -1;
