@@ -161,6 +161,9 @@ void HttpCltXact::finish(Error err) {
 		}
 	}
 
+	if (theOid.aborted())
+		theActualRepType = TheUnknownContentId;
+
 	CltXact::finish(err);
 }
 
@@ -402,7 +405,7 @@ void HttpCltXact::makeExplicitReq(ostream &os) {
 	}
 
 	// where we should abort
-	theAbortSize = theAbortCoord.pos(theReqSize.expected(), theReqBodySize);
+	theAbortSize = theAbortCoord.pos(theReqSize.header(), theReqBodySize);
 }
 
 void HttpCltXact::finishReqHdrs(ostream &os, bool forceDump) {
@@ -416,6 +419,7 @@ void HttpCltXact::finishReqHdrs(ostream &os, bool forceDump) {
 	buf.append("\r\n", Min(buf.spaceSize(), Size(2))); // end-of-header
 
 	Size fullSize = buf.space() - reqStart;
+	theReqSize.header(fullSize);
 	if (theReqBodySize.known())
 		fullSize += theReqBodySize;
 	theReqSize.expect(fullSize);
@@ -714,7 +718,8 @@ Error HttpCltXact::interpretHeader() {
 			if (theRepHdr.theContSize >= 0)
 				theRepSize.expect(theRepHdr.theHdrSize + theRepHdr.theContSize);
 			else
-			if (theRepHdr.persistentConnection())
+			if (theRepHdr.persistentConnection() &&
+				!theRepHdr.multiRange())
 				return errPersistButNoCLen;
 		}
 	} else {
@@ -1326,6 +1331,7 @@ Error HttpCltXact::noteEmbedded(ReqHdr &hdr) {
 		hdr.theUri.oid.ims304(theOid.ims304());
 		hdr.theUri.oid.reload(theOid.reload());
 		hdr.theUri.oid.get(true);
+		theOwner->selectScheme(hdr.theUri.oid);
 		theOwner->noteEmbedded(this, hdr.theUri.oid);
 	}
 
