@@ -11,7 +11,11 @@
 ContentMgr TheContentMgr;
 
 
-ContentMgr::ContentMgr(): theCfgCounter(0) {
+ContentMgr::ContentMgr():
+	theCfgCounter(0), theNormalContentStart(0), didInit(false) {
+}
+
+void ContentMgr::init() {
 	makeFakeContentType(TheForeignContentId, "foreign");
 	makeFakeContentType(TheBodilessContentId, "bodiless");
 	makeFakeContentType(TheUnknownContentId, "unknown");
@@ -20,6 +24,11 @@ ContentMgr::ContentMgr(): theCfgCounter(0) {
 }
 
 ContentCfg *ContentMgr::makeCfg() {
+	if (!didInit) {
+		didInit = true;
+		init();
+	}
+
 	ContentCfg *cfg = new ContentCfg(theCfgCounter++);
 	return cfg;
 }
