@@ -22,11 +22,13 @@ class ContentMgr: public ConfigSymMgr<ContentSym, ContentCfg> {
 		int normalContentStart() const { return theNormalContentStart; }
 
 	protected:
+		void init();
 		virtual ContentCfg *makeCfg();
 		void makeFakeContentType(int &id, const String &kind);
 
 		int theCfgCounter;
 		int theNormalContentStart;
+		bool didInit; // init() was called
 };
 
 extern ContentMgr TheContentMgr;
