@@ -179,7 +179,7 @@ ListSym *PglSemx::makeList(const ParsSym &pgl) {
 
 void PglSemx::addListItem(ListSym &list, const ParsSym &expr) {
 	ExpressionSym *item = makeExpression(expr);
-	mustBeDefined(*item, "list item");
+	mustBeDefined(item, "list item", expr.loc());
 	list.add(*item);
 	delete item;
 }
@@ -225,7 +225,7 @@ void PglSemx::addArrayItem(ArraySym &arr, bool ofNames, const ParsSym &expr, dou
 	ExpressionSym *item = ofNames ?
 		(ExpressionSym*) new StringSym(objName(expr)) :
 		(ExpressionSym*) makeExpression(expr);
-	mustBeDefined(*item, "component of an array");
+	mustBeDefined(item, "component of an array", expr.loc());
 	arr.add(*item, prob);
 	delete item;
 }
@@ -1061,7 +1061,7 @@ ExpressionSym *PglSemx::makeClone(const ExpressionSym &expr, const ExpressionSym
 	if (IntSym *factori = (IntSym *) factors.clone(IntSym::TheType)) {
 		const int factor = factori->val();
 		if (factor >= 0) {
-			mustBeDefined(expr, "clone subject");
+			mustBeDefined(&expr, "clone subject");
 			ArraySym *a = new ArraySym;
 			if (factor > 0)
 				a->add(ClonerSym(expr, factori->val()));
@@ -1216,9 +1216,11 @@ void PglSemx::assign(SynSymTblItem *i, const SynSym &newVal, const SrcLoc &loc)
 	}
 }
 
-void PglSemx::mustBeDefined(const ExpressionSym &expr, const char *descr) const {
-	if (expr.isA(UndefOpExprSym::TheType))
-		cerr << expr.loc() << "undefined " << descr << endl << xexit;
+void PglSemx::mustBeDefined(const ExpressionSym *const expr, const char *const descr, const SrcLoc &defaultLoc) const {
+	if (!expr || expr->isA(UndefOpExprSym::TheType)) {
+		cerr << (expr ? expr->loc() : defaultLoc) << "undefined "
+			<< descr << endl << xexit;
+	}
 }
 
 void PglSemx::unknownRhs(const ParsSym &pgl) const {
