@@ -654,7 +654,8 @@ void HttpSrvXact::put2xxContentHead(ostream &os) {
 	if (theRepContentCfg->multipleContentCodings())
 		os << hfVaryAcceptEncoding;
 
-	if (theRepContentCfg->calcChecksumNeed(theOid))
+	// XXX: no checksum for 206 until ContentCfg::calcChecksum is fixed
+	if (!theOid.range() && theRepContentCfg->calcChecksumNeed(theOid))
 		putChecksum(*theRepContentCfg, theOid, os);
 
 	if (theOwner->isCookieSender)
