@@ -10,7 +10,7 @@
 
 typedef void (*xnew_handler)();
 
-bool xset_new_handler(xnew_handler h) {
+inline bool xset_new_handler(xnew_handler h) {
 	// VC++ has deliberately broken set_new_handler
 	// and a different interface for _set_new_handler
 #if defined(HAVE__SET_NEW_HANDLER)
